@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import abc
 import inspect
 from typing import ClassVar, Generic, Optional, Type, TypeVar, TYPE_CHECKING
 
@@ -9,18 +10,43 @@ from basic_notion.base import NotionItemBase
 from basic_notion.attr import ItemAttrDescriptor
 from basic_notion.parent import ParentDatabase, ParentPage
 from basic_notion.data_gen import PageDataGen
+from basic_notion.property import PageProperty
+from basic_notion.schema import Schema
 
 if TYPE_CHECKING:
     from basic_notion.parent import Parent
-    from basic_notion.property import PageProperty
+
+
+def _make_schema_for_page_cls(page_cls: type) -> Schema:
+    return Schema({
+        name: prop
+        for name, prop in inspect.getmembers(page_cls)
+        if isinstance(prop, PageProperty)
+    })
+
+
+class NotionPageMetaclass(abc.ABCMeta):
+    # abc.ABCMeta is needed here for compatibility with NotionItemBase
+
+    """Metaclass for NotionPage that adds `schema` to its attributes"""
+
+    def __new__(cls, name: str, bases: tuple[type, ...], dct: dict):
+        if 'schema' in bases:
+            raise TypeError('Attribute "schema" is reserved in NotionPage subclasses')
+
+        new_cls = super().__new__(cls, name, bases, dct)
+        new_cls.schema = _make_schema_for_page_cls(new_cls)  # type: ignore
+        return new_cls
 
 
 @attr.s(slots=True)
-class NotionPage(NotionItemBase):
+class NotionPage(NotionItemBase, metaclass=NotionPageMetaclass):
     """
     Represents a page object returned by the Notion API
     """
 
+    schema: Schema  # defined in metaclass
+
     OBJECT_TYPE_KEY_STR = 'object'
     OBJECT_TYPE_STR = 'page'
     DATA_GEN_CLS = PageDataGen
@@ -37,22 +63,13 @@ class NotionPage(NotionItemBase):
     properties_data: ItemAttrDescriptor[dict[str, dict]] = ItemAttrDescriptor(key=('properties',))
     parent_data: ItemAttrDescriptor[dict[str, dict]] = ItemAttrDescriptor(key=('parent',))
 
-    @classmethod
-    def get_class_fields(cls) -> dict[str, PageProperty]:
-        from basic_notion.property import PageProperty
-        return {
-            name: prop
-            for name, prop in inspect.getmembers(cls)
-            if isinstance(prop, PageProperty)
-        }
-
     @property
     def parent(self) -> Parent:
         parent_type = self.parent_data['type']
         parent: Parent
 
         # TODO: This would be a great place to use match-case,
-        #   but mypy doesn't support it yet: https://github.com/python/mypy/pull/10191
+        #  but mypy doesn't support it yet: https://github.com/python/mypy/pull/10191
 
         if parent_type == ParentPage.OBJECT_TYPE_STR:
             parent = ParentPage(data=self.parent_data)
@@ -63,7 +80,8 @@ class NotionPage(NotionItemBase):
 
         return parent
 
-    # TODO: properties that convert `ct` and `let` into datetimes. Something wrong with isoformat
+    # TODO: properties that convert `created_time` and `last_edited_time` into datetimes.
+    #  Something wrong with isoformat
 
 
 _RESULT_ITEM_TV = TypeVar('_RESULT_ITEM_TV', bound=NotionPage)
